==> nsc-2.0.1-106-GA.update.tgz: var/webconfig/SAFe/system/language/english/form_validation_lang.php <==
<?php

$lang['required']			= "The %s field is required.";
$lang['isset']				= "The %s field must have a value.";
$lang['valid_email']		= "The %s field must contain a valid email address.";
$lang['valid_emails']		= "The %s field must contain all valid email addresses.";
$lang['valid_url']			= "The %s field must contain a valid URL.";
$lang['valid_ip_or_domain']			= "The %s field must contain a IP or domain.";
$lang['valid_time']			= "The %s field must contain a valid time (HH:MM:SS).";
$lang['valid_date']			= "The %s field must contain a valid date (YYYY-MM-DD).";
$lang['valid_ip']			= "The %s field must contain a valid IP.";
$lang['min_length']			= "The %s field must be at least %s characters in length.";
$lang['max_length']			= "The %s field can not exceed %s characters in length.";
$lang['exact_length']		= "The %s field must be exactly %s characters in length.";
$lang['alpha']				= "The %s field may only contain alphabetical characters.";
$lang['alpha_numeric']		= "The %s field may only contain alpha-numeric characters.";
$lang['alpha_dash']			= "The %s field may only contain alpha-numeric characters, underscores, dashes and dot.";
$lang['numeric']			= "The %s field must contain only numbers.";
$lang['is_numeric']			= "The %s field must contain only numeric characters.";
$lang['integer']			= "The %s field must contain an integer.";
$lang['regex_match']		= "The %s field is not in the correct format.";
$lang['matches']			= "The %s field does not match the %s field.";
$lang['not_matches']			= "The %s field matches the %s field.";
$lang['is_unique'] 			= "The %s field must contain a unique value.";
$lang['is_natural']			= "The %s field must contain only positive numbers.";
$lang['is_natural_no_zero']	= "The %s field must contain a number greater than zero.";
$lang['decimal']			= "The %s field must contain a decimal number.";
$lang['less_than']			= "The %s field must contain a number less than %s.";
$lang['less_or_equal']			= "The %s field must contain a number less than or equal to %s.";
$lang['greater_than']		= "The %s field must contain a number greater than %s.";
$lang['greater_or_equal']		= "The %s field must contain a number greater than or equal to %s.";
$lang['different_than']		= "The %s field must be different than %s.";
$lang['valid_ip_or_blank_or_any']		="The %s field must contain an IP Address or must be left empty.";
$lang['valid_date_time'] = "The %s field must contain a valid date time (YYYY-MM-DD HH:MM:SS).";
$lang['valid_uuid'] = "The %s field must contain a valid UUID.";
$lang['valid_ext_sip_ip'] = "The field contains an invalid %s";
$lang['sip_fail_response_code'] = "This field does not contain a valid %s";
$lang['valid_ip_port_domain'] = "The %s field must contain a valid IP, domain name, or be in IP:PORT notation.";
$lang['src_ip_filter_rule'] = "The field does not contain a valid %s";
$lang['in_list'] = "The %s field contains an invalid option.";
$lang['date_greater_than']		= "The %s field must contain a date greater than %s.";
$lang['valid_sip_account']		= "The %s field must contain a valid SIP account.";
$lang['valid_ip_or_prefix']		= "The %s field must contain a valid IP or Subnetwork like '10.20.1.0/24'.";


/* End of file form_validation_lang.php */
/* Location: ./system/language/english/form_validation_lang.php */

==> nsc-2.1.6-40-GA.update.tgz: var/webconfig/SAFe/system/language/english/form_validation_lang.php <==
<?php

$lang['required']			= "The %s field is required.";
$lang['isset']				= "The %s field must have a value.";
$lang['valid_email']		= "The %s field must contain a valid email address.";
$lang['valid_emails']		= "The %s field must contain all valid email addresses.";
$lang['valid_url']			= "The %s field must contain a valid URL.";
$lang['valid_ip_or_domain']			= "The %s field must contain a IP or domain.";
$lang['valid_time']			= "The %s field must contain a valid time (HH:MM:SS).";
$lang['valid_date']			= "The %s field must contain a valid date (YYYY-MM-DD).";
$lang['valid_ip']			= "The %s field must contain a valid IP.";
$lang['min_length']			= "The %s field must be at least %s characters in length.";
$lang['max_length']			= "The %s field can not exceed %s characters in length.";
$lang['exact_length']		= "The %s field must be exactly %s characters in length.";
$lang['alpha']				= "The %s field may only contain alphabetical characters.";
$lang['alpha_numeric']		= "The %s field may only contain alpha-numeric characters.";
$lang['alpha_dash']			= "The %s field may only contain alpha-numeric characters, underscores, dashes and dot.";
$lang['numeric']			= "The %s field must contain only numbers.";
$lang['is_numeric']			= "The %s field must contain only numeric characters.";
$lang['integer']			= "The %s field must contain an integer.";
$lang['regex_match']		= "The %s field is not in the correct format.";
$lang['matches']			= "The %s field does not match the %s field.";
$lang['not_matches']			= "The %s field matches the %s field.";
$lang['is_unique'] 			= "The %s field must contain a unique value.";
$lang['is_natural']			= "The %s field must contain only positive numbers.";
$lang['is_natural_no_zero']	= "The %s field must contain a number greater than zero.";
$lang['decimal']			= "The %s field must contain a decimal number.";
$lang['less_than']			= "The %s field must contain a number less than %s.";
$lang['less_or_equal']			= "The %s field must contain a number less than or equal to %s.";
$lang['greater_than']		= "The %s field must contain a number greater than %s.";
$lang['greater_or_equal']		= "The %s field must contain a number greater than or equal to %s.";
$lang['different_than']		= "The %s field must be different than %s.";
$lang['valid_ip_or_blank_or_any']		="The %s field must contain an IP Address or must be left empty.";
$lang['valid_date_time'] = "The %s field must contain a valid date time (YYYY-MM-DD HH:MM:SS).";
$lang['valid_uuid'] = "The %s field must contain a valid UUID.";
$lang['valid_ext_sip_ip'] = "The field contains an invalid %s";
$lang['sip_fail_response_code'] = "This field does not contain a valid %s";
$lang['valid_ip_port_domain'] = "The %s field must contain a valid IP, domain name, or be in IP:PORT notation.";
$lang['src_ip_filter_rule'] = "The field does not contain a valid %s";
$lang['in_list'] = "The %s field contains an invalid option.";
$lang['not_in_list'] = "The %s field contains an invalid data.";
$lang['date_greater_than']		= "The %s field must contain a date greater than %s.";
$lang['valid_sip_account']		= "The %s field must contain a valid SIP account.";
$lang['valid_ip_or_prefix']		= "The %s field must contain a valid IP or Subnetwork like '10.20.1.0/24'.";
$lang['regex_required']			= "The %s field is required.";
$lang['disabled']			= "The %s field cannot be modified.";
$lang['is_array']			= "The %s field must contain an array.";
$lang['valid_port_number'] = "The %s field must contain a valid PORT number between 1 and 65535.";
$lang['ssl_ip_or_domain']	    = "The %s field must contain a valid IP or domain, or be in ssh://IP notation.";

/* End of file form_validation_lang.php */
/* Location: ./system/language/english/form_validation_lang.php */
